searchData={"items":[{"type":"module","title":"Periods","doc":"Periods increments of time.\n\nPeriods are designed to represent fractions of time from milliseconds to decades\nin order to help make working with various time based structs easier.\n\nPeriods can be converted, added, and subtracted.\n\nBy default the base value is a `second` you can choose a different base for your\napplication by setting the `:default_value` in you Application config.\n\nThe only limitation are months. Due to the inconsistency of a period of a month from 28-31\ndays conversion and mathematical operations are limited.","ref":"Periods.html"},{"type":"function","title":"Periods.add/2","doc":"Add a Period to a Period, Time, Date, DateTime, or NaiveDateTime.\n\nNote: `Months` have limited additive properties\n\nWhen performing addition of periods all values will be converted to the lowest\nunit value. For example if you add a Period of days to a Period of seconds then\nthe result will be seconds.\n\nWhen adding a period to an Elixir date/time struct the return will be the Elixir\ndate/time struct.\n\nNote: Since there is conversion involved you may loose fractional values such as\nadding 1 millisecond to a Date.","ref":"Periods.html#add/2"},{"type":"function","title":"Examples - Periods.add/2","doc":"iex> Periods.add(%Period{amount: 10, unit: :day}, %Period{amount: 1000, unit: :second})\n    %Period(amount: 865000, unit: :second)\n\n    iex> DateTime.utc_now() |> Periods.add(%Period{amount: 1000, unit: :second})\n    ~U[2023-07-09 14:14:50.896089Z]\n\n    iex> Time.utc_now() |> Periods.add(%Period{amount: 1000, unit: :second})\n    ~T[14:17:04.932992]\n\n    iex> today = Date.utc_today()\n    ~D[2023-07-09]\n    iex> Periods.add(today, %Period{amount: 1, unit: :millisecond})\n    ~D[2023-07-09]","ref":"Periods.html#add/2-examples"},{"type":"function","title":"Periods.all_units/0","doc":"Returns a list of all the current values Periods supports","ref":"Periods.html#all_units/0"},{"type":"function","title":"Examples - Periods.all_units/0","doc":"iex> Periods.all_units()\n    [:millisecond, :second, :minute, :hour, :day, :week, :month, :year, :decade]","ref":"Periods.html#all_units/0-examples"},{"type":"function","title":"Periods.convert/2","doc":"Convert a Period from one unit to another unit.\n\nNote: `Months` have limited conversion properties\n\nWhen converting from a lower unit such as milliseconds to a higher unit such as seconds,\nsince all return values are integers, you will loose precision due to rounding. In some\nconversion scenarios you may get a 0 value.","ref":"Periods.html#convert/2"},{"type":"function","title":"Examples - Periods.convert/2","doc":"iex> Periods.convert(%Period{amount: 10, unit: :day}, :second)\n    %Periods.Period{amount: 864000, unit: :second}\n\n    iex> Periods.convert(%Period{amount: 864000, unit: :second}, :day)\n    %Period{amount: 10, unit: :day}\n\n    iex> Periods.convert(%Period{amount: 10, unit: :year}, :month)\n    %Periods.Period{amount: 120, unit: :month}\n\n    iex> Periods.convert(%Period{amount: 10, unit: :second}, :week)\n    %Periods.Period{amount: 0, unit: :week}\n\n    iex> Periods.convert(%Period{amount: 1000, unit: :second}, :month)\n    {:error, {:cannot_convert_to_month, :month}}","ref":"Periods.html#convert/2-examples"},{"type":"function","title":"Periods.convert!/2","doc":"Converts and returns a %Period{} or raise error.\n\nSame as `convert/2` excepts raises a `%ConversionError{}` when unsuccessful","ref":"Periods.html#convert!/2"},{"type":"function","title":"Examples - Periods.convert!/2","doc":"iex> Periods.convert!(%Period{amount: 10, unit: :day}, :second)\n    %Periods.Period{amount: 864000, unit: :second}\n\n    iex> Periods.convert!(%Period{amount: 1000, unit: :second}, :month)\n    ** (Periods.Conversion.ConversionError) unit: bad type","ref":"Periods.html#convert!/2-examples"},{"type":"function","title":"Periods.default_unit/0","doc":"Returns the value set by your Application environment or the default :second","ref":"Periods.html#default_unit/0"},{"type":"function","title":"Examples - Periods.default_unit/0","doc":"iex> Periods.default_unit()\n    :second","ref":"Periods.html#default_unit/0-examples"},{"type":"function","title":"Periods.diff/3","doc":"Get the difference of Time, Date, DateTime, NaiveDateTime in a Period.\n\nOptional add unit for conversion. Some units will loose precision because fractional\nunits are not supported. For example converting milliseconds to days will round to\ninteger day.\n\nDefault conversion units will be dependant upon the struct.\n- [Time](https://hexdocs.pm/elixir/Time.html) defaults to `:second`\n- [Date](https://hexdocs.pm/elixir/Date.html) defaults to `:day`\n- [DateTIme](https://hexdocs.pm/elixir/DateTime.html) defaults to `:second`\n- [NaiveDateTime](https://hexdocs.pm/elixir/NaiveDateTime.html) defaults to `:second`\n\nWhen getting the difference between two DateTimes with different timezones `diff/3`\nwill convert both timezones to UTC then calculate the difference.\n\nFor DateTime currently using the [Tz](https://hex.pm/packages/tz) hex package to\nhelp adjust timezones.\n\n**In order to use Timezone conversion** please add to your application config:\n```elixir\nconfig :elixir, :time_zone_database, Tz.TimeZoneDatabase\n```","ref":"Periods.html#diff/3"},{"type":"function","title":"Examples - Periods.diff/3","doc":"iex> Periods.diff(~T[21:30:43], ~T[13:50:17])\n    {:ok, %Periods.Period{amount: 27626, unit: :second}}\n\n    iex> Periods.diff(~D[2000-03-15], ~D[2000-01-01])\n    {:ok, %Periods.Period{amount: 74, unit: :day}}\n\n    iex> Periods.diff(~D[2000-03-15], ~D[2000-01-01], :second)\n    {:ok, %Periods.Period{amount: 6393600, unit: :second}}\n\n    iex> Periods.diff(#DateTime , #DateTime )\n    {:ok, %Periods.Period{amount: 3292418, unit: :second}}","ref":"Periods.html#diff/3-examples"},{"type":"function","title":"Periods.new/1","doc":"Create a new Period through a variety of input types.","ref":"Periods.html#new/1"},{"type":"function","title":"Examples - Periods.new/1","doc":"iex> Periods.new(%{amount: 100, unit: :second})\n    {:ok, %Periods.Period{amount: 100, unit: :second}}\n\n    iex> Periods.new(%{amount: \"100\", unit: \"second\"})\n    {:ok, %Periods.Period{amount: 100, unit: :second}}\n\n    iex> Periods.new({100, \"second\"})\n    {:ok, %Periods.Period{amount: 100, unit: :second}}\n\n    iex> Periods.new(\"100\")\n    {:ok, %Periods.Period{amount: 100, unit: :second}}","ref":"Periods.html#new/1-examples"},{"type":"function","title":"Periods.new/2","doc":"Creates a new Period.","ref":"Periods.html#new/2"},{"type":"function","title":"Examples - Periods.new/2","doc":"iex> Periods.new(100, :second)\n    {:ok, %Periods.Period{amount: 100, unit: :second}}\n\n    iex> Periods.new(\"100\", \"second\")\n    {:ok, %Periods.Period{amount: 100, unit: :second}}","ref":"Periods.html#new/2-examples"},{"type":"function","title":"Periods.new!/1","doc":"Creates a new Period or raises an error.\n\nSame as `new/1` excepts raises a `%ParserError{}` when unsuccessful","ref":"Periods.html#new!/1"},{"type":"function","title":"Examples - Periods.new!/1","doc":"iex> Periods.new!({100, \"second\"})\n    %Periods.Period{amount: 100, unit: :second}\n\n    iex> Periods.new!(100, :fort_nights)\n    ** (Periods.Conversion.ConversionError) unit: bad type","ref":"Periods.html#new!/1-examples"},{"type":"function","title":"Periods.subtract/2","doc":"Subtract a Period from a Time, Date, DateTime, or NaiveDateTime.\n\nNote: `Months` have limited subtracting properties\n\nWhen performing subtraction of periods all values will be converted to the lowest\nunit value. For example if you subtract a Period of days from a Period of seconds then\nthe result will be seconds.\n\nWhen subtracting a period from an Elixir date/time struct the return will be the Elixir\ndate/time struct.\n\nNote: Since there is conversion involved you may loose fractional values such as\nsubtracting 1 millisecond from a Date.","ref":"Periods.html#subtract/2"},{"type":"function","title":"Examples - Periods.subtract/2","doc":"iex> Periods.subtract(%Period{amount: 10, unit: :day}, %Period{amount: 1000, unit: :second})\n    %Periods.Period{amount: 863000, unit: :second}\n\n    iex> DateTime.utc_now() |> Periods.subtract(%Period{amount: 1000, unit: :second})\n    ~U[2023-07-09 14:08:32.916532Z]\n\n    iex> Time.utc_now() |> Periods.subtract(%Period{amount: 1000, unit: :second})\n    ~T[14:08:45.831176]\n\n    iex> today = Date.utc_today()\n    ~D[2023-07-10]\n    iex> Periods.subtract(today, %Period{amount: 10000000000000, unit: :millisecond})\n    ~D[1706-08-21]\n    iex> Periods.subtract(today, %Period{amount: 3, unit: :year})\n    ~D[2020-07-10]","ref":"Periods.html#subtract/2-examples"},{"type":"function","title":"Periods.to_integer/2","doc":"Output a Period as an Integer with optional conversion unit.","ref":"Periods.html#to_integer/2"},{"type":"function","title":"Examples - Periods.to_integer/2","doc":"iex> Periods.to_integer(%Period{amount: 10, unit: :day}, :second)\n    864000\n\n    iex> Periods.to_integer(%Period{amount: 10, unit: :day})\n    10\n\n    iex> Periods.to_integer(%Period{amount: 1000, unit: :second}, :month)\n    {:error, {:cannot_convert_to_month, :second}}","ref":"Periods.html#to_integer/2-examples"},{"type":"function","title":"Periods.to_string/2","doc":"Output a Period as a String with optional conversion unit.","ref":"Periods.html#to_string/2"},{"type":"function","title":"Examples - Periods.to_string/2","doc":"iex> Periods.to_string(%Period{amount: 10, unit: :day}, :second)\n    \"864000 seconds\"\n\n    iex> Periods.to_string(%Period{amount: 10, unit: :day})\n    \"10 days\"\n\n    iex> Periods.to_string(%Period{amount: 1, unit: :day})\n    \"1 day\"\n\n    iex> Periods.to_string(%Period{amount: 1000, unit: :second}, :month)\n    {:error, {:cannot_convert_to_month, :second}}","ref":"Periods.html#to_string/2-examples"},{"type":"type","title":"Periods.amount/0","doc":"","ref":"Periods.html#t:amount/0"},{"type":"type","title":"Periods.computation_type/0","doc":"","ref":"Periods.html#t:computation_type/0"},{"type":"type","title":"Periods.difference_type/0","doc":"","ref":"Periods.html#t:difference_type/0"},{"type":"type","title":"Periods.error_type/0","doc":"","ref":"Periods.html#t:error_type/0"},{"type":"type","title":"Periods.parse_type/0","doc":"","ref":"Periods.html#t:parse_type/0"},{"type":"type","title":"Periods.unit/0","doc":"","ref":"Periods.html#t:unit/0"},{"type":"module","title":"Periods.Ecto.MapType","doc":"Provides a type for Ecto to store a Period of time.\nThe underlying data type should be a map(JSON).\nSuitable for databases that do not support composite types,\nbut support JSON (e.g. MySQL and versions of CockroachDB).","ref":"Periods.Ecto.MapType.html"},{"type":"module","title":"Migration - Periods.Ecto.MapType","doc":"create table(:timers) do\n      add :timer_period, :map\n    end","ref":"Periods.Ecto.MapType.html#module-migration"},{"type":"module","title":"Schema - Periods.Ecto.MapType","doc":"schema \"timers\" do\n      field :timer_period, Periods.Ecto.MapType\n    end","ref":"Periods.Ecto.MapType.html#module-schema"},{"type":"function","title":"Periods.Ecto.MapType.cast/1","doc":"","ref":"Periods.Ecto.MapType.html#cast/1"},{"type":"function","title":"Periods.Ecto.MapType.dump/1","doc":"","ref":"Periods.Ecto.MapType.html#dump/1"},{"type":"function","title":"Periods.Ecto.MapType.embed_as/1","doc":"","ref":"Periods.Ecto.MapType.html#embed_as/1"},{"type":"function","title":"Periods.Ecto.MapType.equal?/2","doc":"","ref":"Periods.Ecto.MapType.html#equal?/2"},{"type":"function","title":"Periods.Ecto.MapType.load/1","doc":"","ref":"Periods.Ecto.MapType.html#load/1"},{"type":"function","title":"Periods.Ecto.MapType.type/0","doc":"","ref":"Periods.Ecto.MapType.html#type/0"},{"type":"module","title":"Periods.Errors","doc":"","ref":"Periods.Errors.html"},{"type":"exception","title":"Periods.Computation.ComputationError","doc":"","ref":"Periods.Computation.ComputationError.html"},{"type":"exception","title":"Periods.Conversion.ConversionError","doc":"","ref":"Periods.Conversion.ConversionError.html"},{"type":"exception","title":"Periods.Parser.ParserError","doc":"","ref":"Periods.Parser.ParserError.html"},{"type":"extras","title":"Periods","doc":"Periods\n=======\n[![Hex.pm version](https://img.shields.io/hexpm/v/periods.svg)](http://hex.pm/packages/periods) [![Hex.pm downloads](https://img.shields.io/hexpm/dt/periods.svg)](https://hex.pm/packages/periods)\n\nA helper for converting and performing math operations on values of Time, Date, DateTime, and NaiveDateTime along with storing in database with Ecto.Type.\n\nPeriods are designed to represent fractions of time from milliseconds to decades\nin order to help make working with various time based structs easier.\n\nPeriods can be converted, added, and subtracted.\n\nBy default the base value is a `second` you can choose a different base for your\napplication by setting the `:default_value` in you Application config.\n\nThe only limitation are months. Due to the inconsistency of a period of a month from 28-31\ndays conversion and mathematical operations are limited.\n\nThank you to all the people working on Money and Ecto. Those projects inspired parts of this design.","ref":"readme.html"},{"type":"extras","title":"Examples - Periods","doc":"```elixir\n  # Create a new Period\n  iex> Periods.new({1000, :day})\n  {:ok, %Periods.Period{amount: 1000, unit: :day}}\n\n  # Convert from one unit to another easily\n  iex> Periods.convert(%Period{amount: 10, unit: :day}, :second)\n  %Periods.Period{amount: 864000, unit: :second}\n\n  # Addition of periods to Time, Date, DateTime, and NaiveDateTime along with other Periods\n  # Note will convert to lowest unit.\n  iex> Periods.add(%Period{amount: 100, unit: :day}, %Period{amount: 1000, unit: :second})\n  %Periods.Period{amount: 8641000, unit: :second}\n\n  iex> DateTime.utc_now() |> Periods.add(%Period{amount: 100, unit: :day})\n  ~U[2023-10-18 02:15:58.766819Z]\n\n  # Subtraction of Periods from Time, Date, DateTime, and NaiveDateTime along with other Periods\n  # Note here Date only accepts days for add/subtract thus Period auto converts.\n  iex> today = Date.utc_today()\n  ~D[2023-07-10]\n  iex> Periods.subtract(today, %Period{amount: 10000000000000, unit: :millisecond})\n  ~D[1706-08-21]\n  iex> Periods.subtract(today, %Period{amount: 3, unit: :year})\n  ~D[2020-07-10]\n\n  # Get the difference between two Elixir structs of Time, Date, DateTime, NaiveDateTime in a Period.\n  iex> Periods.diff(~T[21:30:43], ~T[13:50:17])\n  {:ok, %Periods.Period{amount: 27626, unit: :second}}\n\n  iex> Periods.diff(~D[2000-03-15], ~D[2000-01-01])\n  {:ok, %Periods.Period{amount: 74, unit: :day}}\n\n  iex> Periods.diff(~D[2000-03-15], ~D[2000-01-01], :second)\n  {:ok, %Periods.Period{amount: 6393600, unit: :second}}\n\n  iex> Periods.diff(#DateTime , #DateTime )\n  {:ok, %Periods.Period{amount: 3292418, unit: :second}}\n\n```","ref":"readme.html#examples"},{"type":"extras","title":"Ecto Type - Periods","doc":"For easy database storage and application use.\n```elixir\n  # Migration\n  create table(:timers) do\n    add :timer_period, :map\n  end\n\n  # In Module Schema\n  schema \"timers\" do\n    field :timer_period, Periods.Ecto.MapType\n  end\n```","ref":"readme.html#ecto-type"},{"type":"extras","title":"Installation - Periods","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `periods` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:periods, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"}],"content_type":"text/markdown"}